function [n, gm, lh] = det_number(data, g)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Estimate the number of endmembers in a hyperspectral image
% Bin Luo, Jocelyn Chanussot, Sylvain Doute, and Liangpei Zhang, 
% Empirical Automatic Estimation of the Number of Endmembers in Hyperspectral Images,
% IEEEIEEE GEOSCIENCE AND REMOTE SENSING LETTERS, VOL. 10, NO. 1, 24-28, JANUARY 2013
% Usage:
% [n, gm, lh] = det_number(data, g)
% Input:
% data -- input image
% g -- the bands used for estimating the number of endmembers
% Output:
% n -- local maxima of likelihood function, the first element
%      can be used as the number of endmembers
% gm -- global maximum
% lk -- likelihood function
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



if size(data, 1)<size(data,2)
    data = data';
end
ndata  = data(:,g);
K = cov(ndata);
 M = mean(ndata)'*mean(ndata);
R = K+M;
 er = sort(eig(R), 'descend');
 ek = sort(eig(K), 'descend');
[lh m] = calc_new_lh(er, ek, size(data, 1));
n = find_local_max(lh);
nlh = lh(1:size(data,2)/2);
gm  =find(nlh==max(nlh));